@@ -50,17 +50,6 @@ class Crp:
         
         return df_1,log_file
 
-#-----------------------------------------------------------------------------------------------------------------------
-
-
-
-
-
-
-
-
-
-
 
     def getTrainingframe(self,df,dateFlag_sep,date_flag_min):
         """
@@ -70,6 +59,7 @@ class Crp:
             date_flag_min     -> Min date for training frame
         ---------------------
         Output:
+
         """
     #     dateFlag_sep = np.max(df['order_date']) - pd.DateOffset(months=timeFlag)
     #     date_flag_min = dateFlag_sep - pd.DateOffset(months=train_window)
@@ -78,7 +68,6 @@ class Crp:
         
         return df 
 
-#--------------------------------------------------------------------------------------------------------------------------
 
     def getTargetframe(self,df,dateFlag_sep,lag):
         """
@@ -97,7 +86,6 @@ class Crp:
         
         return df
 
-# --------------------------------------------------------------------------------------------------------------------------
 
     def getTargetValues(self,train_data,target_data):
         """
@@ -121,9 +109,6 @@ class Crp:
         #Output
         return target
 
- #---------------------------------------------------------------------------------------------------------------------------
-
-
 
     def getRecency(self,matrix,dateFlag):
         """
@@ -137,10 +122,10 @@ class Crp:
         """
         matrix['Recency'] = matrix.apply(lambda x: dateFlag - pd.to_datetime(x.order_date),axis =1).dt.days
         
-        output = matrix
+        
         
         # Output
-        return output
+        return matrix
 
 
 
@@ -171,7 +156,6 @@ class Crp:
     def getTotalSpentLMonth(self,train_df,dateFlag_sep,df_matrix):
         """
         Params:
-pwd
 
         -----------------
         Output:
@@ -197,13 +181,10 @@ pwd
         # df_matrix = df_matrix.rename(columns = {'totalprice':'Last_Month_Total_Spent'})
         
         
-        
-        output = df_matrix
-        
-        return output
+        return df_matrix
+
 
 
-# ----------------------------------------------------------------------------------
 
     def getFeaturesMatrix(self,train_df,org_df,timeFlag,items_dataset,customer_name,train_window,sq_pass):
         """
@@ -225,7 +206,7 @@ pwd
         grp = train_df.groupby('customerid')
 
         grp_dict = {'order_date':'max','id':'count','totalprice':'sum','buyeracceptsmarketing':'max',
-                    'billingaddresscountrycode':'unique'}
+                    'billingaddresszip':'unique'}
 
         df_matrix = grp.agg(grp_dict).rename(columns={'id':'num_orders','totalprice':'TotalSpent'})
         # Recency Feature
@@ -249,9 +230,6 @@ pwd
         return output
 
 
-
-# --------------------------------------------------------------------------------------------------------------------------------
-
     def getMergedDF(self,data_list,key):
         """
         Params: 
@@ -269,10 +247,6 @@ pwd
         return output
 
 
-# ------------------------------------------------------------------------------------------------------------------------------------
-
-
-
     def prepareDF(self,original_dataset,dateFlag_sep,date_flag_min,lag,items_dataset,customer_name,train_window,sq_pass):
         """
         Params:
@@ -311,9 +285,9 @@ pwd
         
         
         return output
-# -----------------------------------------------------------------------------------------------
 
-    def buildDF(self,original_dataset,lag,train_window,items_dataset,customer_name,sq_pass):
+
+    def buildDF(self,original_dataset:pd.DataFrame,lag:int,train_window:int,customer_name,sq_pass,items_dataset:pd.DataFrame = None):
         """
         Params:
             original_dataset - > the original raw data 
